"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var common = require("./image-cache-it.common");
var fs = require("tns-core-modules/file-system");
var utils = require("tns-core-modules/utils/utils");
var imageSrc = require("tns-core-modules/image-source");
var view_1 = require("tns-core-modules/ui/core/view");
var image_cache_it_common_1 = require("./image-cache-it.common");
global.moduleMerge(common, exports);
var RoundedCornersTransformation = jp.wasabeef.picasso.transformations.RoundedCornersTransformation;
var ImageCacheIt = (function (_super) {
    __extends(ImageCacheIt, _super);
    function ImageCacheIt() {
        return _super.call(this) || this;
    }
    ImageCacheIt.prototype.createNativeView = function () {
        this.picasso = com.squareup.picasso.Picasso.get();
        return new android.widget.ImageView(this._context);
    };
    ImageCacheIt.prototype.initNativeView = function () {
        if (this.imageUri) {
            this.builder = this.picasso.load(this.getImage(this.imageUri));
        }
        if (this.stretch) {
            this.resetImage();
        }
        if (this.builder) {
            if (this.placeHolder) {
                this.builder.placeholder(imageSrc.fromFileOrResource(this.placeHolder).android);
            }
            if (this.errorHolder) {
                this.builder.error(imageSrc.fromFileOrResource(this.errorHolder).android);
            }
            if (this.resize &&
                this.resize !== undefined &&
                this.resize.split(',').length > 1) {
                this.builder.resize(parseInt(this.resize.split(',')[0], 10), parseInt(this.resize.split(',')[1], 10));
            }
            this.builder.into(this.nativeView);
        }
    };
    ImageCacheIt.prototype[common.imageUriProperty.getDefault] = function () {
        return undefined;
    };
    ImageCacheIt.prototype[common.imageUriProperty.setNative] = function (src) {
        this.builder = this.picasso.load(this.getImage(this.imageUri));
        if (!this.builder) {
            return src;
        }
        if (this.stretch) {
            this.resetImage();
        }
        this.builder.into(this.nativeView);
        return src;
    };
    ImageCacheIt.prototype[common.resizeProperty.setNative] = function (resize) {
        if (!this.builder) {
            return resize;
        }
        if (resize && resize !== undefined && resize.split(',').length > 1) {
            this.builder.resize(parseInt(resize.split(',')[0], 10), parseInt(resize.split(',')[1], 10));
        }
        return resize;
    };
    ImageCacheIt.prototype.getImage = function (src) {
        var nativeImage;
        if (src.substr(0, 1) === '/') {
            nativeImage = new java.io.File(nativeImage);
        }
        else if (src.startsWith('~/')) {
            nativeImage = new java.io.File(fs.path.join(fs.knownFolders.currentApp().path, src.replace('~/', '')));
        }
        else if (src.startsWith('http')) {
            nativeImage = src;
        }
        else if (src.startsWith('res://')) {
            nativeImage = utils.ad.resources.getDrawableId(src.replace('res://', ''));
        }
        return nativeImage;
    };
    ImageCacheIt.prototype[common.stretchProperty.getDefault] = function () {
        return 'aspectFit';
    };
    ImageCacheIt.prototype[common.stretchProperty.setNative] = function (value) {
        if (!this.builder)
            return value;
        this.resetImage(true);
        return value;
    };
    ImageCacheIt.prototype.clearItem = function () { };
    ImageCacheIt.prototype.setBorderAndRadius = function () {
        this.builder
            .transform(new RoundedCornersTransformation(view_1.layout.toDevicePixels(this.borderTopLeftRadius), view_1.layout.toDevicePixels(this.borderTopWidth), RoundedCornersTransformation.CornerType.TOP_LEFT))
            .transform(new RoundedCornersTransformation(view_1.layout.toDevicePixels(this.borderTopRightRadius), view_1.layout.toDevicePixels(this.borderTopWidth), RoundedCornersTransformation.CornerType.TOP_RIGHT))
            .transform(new RoundedCornersTransformation(view_1.layout.toDevicePixels(this.borderBottomLeftRadius), view_1.layout.toDevicePixels(this.borderBottomWidth), RoundedCornersTransformation.CornerType.BOTTOM_LEFT))
            .transform(new RoundedCornersTransformation(view_1.layout.toDevicePixels(this.borderBottomRightRadius), view_1.layout.toDevicePixels(this.borderBottomWidth), RoundedCornersTransformation.CornerType.BOTTOM_RIGHT));
    };
    ImageCacheIt.prototype.resetImage = function (reload) {
        if (reload === void 0) { reload = false; }
        switch (this.stretch) {
            case 'aspectFit':
                this.builder = this.picasso.load(this.getImage(this.imageUri));
                this.setBorderAndRadius();
                this.builder.centerInside();
                if (reload) {
                    this.builder.into(this.nativeView);
                }
                break;
            case 'aspectFill':
                this.builder = this.picasso.load(this.getImage(this.imageUri));
                this.setBorderAndRadius();
                this.builder.centerCrop();
                if (reload) {
                    this.builder.into(this.nativeView);
                }
                break;
            case 'fill':
                this.builder = this.picasso.load(this.getImage(this.imageUri));
                this.setBorderAndRadius();
                this.builder.fit();
                if (reload) {
                    this.builder.into(this.nativeView);
                }
                break;
            case 'none':
            default:
                this.builder = this.picasso.load(this.getImage(this.imageUri));
                this.setBorderAndRadius();
                if (reload) {
                    this.builder.into(this.nativeView);
                }
                break;
        }
    };
    return ImageCacheIt;
}(image_cache_it_common_1.ImageCacheItBase));
exports.ImageCacheIt = ImageCacheIt;
var CornerType;
(function (CornerType) {
    CornerType["ALL"] = "all";
    CornerType["TOP_LEFT"] = "top_left";
    CornerType["TOP_RIGHT"] = "top_right";
    CornerType["BOTTOM_LEFT"] = "bottom_left";
    CornerType["BOTTOM_RIGHT"] = "bottom_right";
    CornerType["TOP"] = "top";
    CornerType["BOTTOM"] = "bottom";
    CornerType["LEFT"] = "left";
    CornerType["RIGHT"] = "right";
    CornerType["OTHER_TOP_LEFT"] = "other_top_left";
    CornerType["OTHER_TOP_RIGHT"] = "other_top_right";
    CornerType["OTHER_BOTTOM_LEFT"] = "other_bottom_left";
    CornerType["OTHER_BOTTOM_RIGHT"] = "other_bottom_right";
    CornerType["DIAGONAL_FROM_TOP_LEFT"] = "diagonal_from_top_left";
    CornerType["DIAGONAL_FROM_TOP_RIGHT"] = "diagonal_from_top_right";
})(CornerType || (CornerType = {}));
//# sourceMappingURL=image-cache-it.android.js.map